@@ -50,6 +50,7 @@ class SpectrumUncurver:
             else:
                 log.error(generalErrorMessage + str(e))
 
+    '''IMAGE FUNCTIONS'''
     def save_uncurved_image(self):
         generalErrorMessage = "File was not saved. "
         try:
@@ -88,6 +89,19 @@ class SpectrumUncurver:
     def show_curved_image(self):
         self.imPIL.show()
 
+    '''PLOT FUNCTIONS'''
+    def sum_all_columns(self):
+        print(self.shiftedImage[1])
+        self.spectrum_data = np.zeros(1, len(self.shiftedImage[1]))
+
+        for xpos in range(len(self.shiftedImage[1])):
+            self.spectrum_data[xpos] = sum(self.shiftedImage[::][xpos])
+
+        print(self.spectrum_data)
+
+    def save_uncurved_plot(self):
+        pass
+
     def show_curvature(self):
         fig, ax = plt.subplot()
         ax.plot(self.gaussianPeakPos)
@@ -203,4 +217,4 @@ if __name__ == "__main__":
     corrector = SpectrumUncurver()
     corrector.load_image('./data/glycerol_06_06_2020_2.tif')
     corrector.uncurve_spectrum_image([640, 700], [0, 400], 'gaussian')
-    corrector.save_image_with_fit()
\ No newline at end of file
+    corrector.sum_all_columns()
\ No newline at end of file
